@@ -25,6 +25,7 @@ import (
 	"os/exec"
 	"strconv"
 	"strings"
+	"errors"
 
 	. "github.com/linuxdeepin/dde-api/dxinput/common"
 	"github.com/linuxdeepin/dde-api/dxinput/utils"
@@ -60,7 +61,13 @@ type Wacom struct {
 }
 
 func NewWacom(id int32) (*Wacom, error) {
-	info := utils.ListDevice().Get(id)
+	infos := utils.ListDevice()
+	if infos == nil {
+		return nil, errors.New("No device")
+	}
+
+	info := infos.Get(id)
+
 	if info == nil {
 		return nil, fmt.Errorf("Invalid device id: %v", id)
 	}
